"""empty message

Revision ID: 05449348d470
Revises: 51e638dafa33
Create Date: 2020-10-04 11:19:56.859868

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '05449348d470'
down_revision = '51e638dafa33'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('contact',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('created_date', sa.DateTime(), nullable=True),
    sa.Column('name', sa.String(length=100), nullable=True),
    sa.Column('email', sa.String(length=100), nullable=True),
    sa.Column('message', sa.String(length=1024), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('contact')
    # ### end Alembic commands ###




from flask import Blueprint
from flask import render_template
from flask import url_for
from flask import redirect
from flask import flash
from flask import request

from .forms import ContactForm
from .models import ContactMessage
from shopyoapi.enhance import base_context

from shopyoapi.html import notify_success



from flask_login import login_required

contact_blueprint = Blueprint(
    "contact",
    __name__,
    url_prefix='/contact',
    template_folder="templates",
)


@contact_blueprint.route("/")
def index():
    context = base_context()
    form = ContactForm()

    context.update({
        'form':form
        })
    return render_template('contact/contact_form.html', **context)


@login_required
@contact_blueprint.route("/validate_message", methods=['GET', 'POST'])
def validate_message():
    if request.method == 'POST':
        form = ContactForm()
        if not form.validate_on_submit():
            flash_errors(form)
            return redirect(url_for('contact.index'))

        name = form.name.data
        email = form.email.data
        message = form.message.data

        contact_message = ContactMessage(
                name=name,
                email=email,
                message=message
            )
        contact_message.insert()
        flash(notify_success('Message submitted!'))
        return redirect(url_for('contact.index'))

@login_required
@contact_blueprint.route("/dashboard", methods=['GET'], defaults={"page": 1})
@contact_blueprint.route("/dashboard/<int:page>", methods=['GET'])
def dashboard(page):
    context = base_context()
    page = page
    per_page = 10
    messages = ContactMessage.query.paginate(page, per_page, error_out=False)
    context.update({
        'messages':messages
        })
    return render_template('contact/dashboard.html', **context)




from flask_wtf import FlaskForm
from wtforms import StringField
from wtforms import TextField
from wtforms import SelectField
from wtforms.fields.html5 import EmailField
from wtforms import SubmitField
from wtforms import PasswordField
from wtforms.validators import DataRequired
from wtforms.validators import Length
from wtforms import TextAreaField


class ContactForm(FlaskForm):
    name = StringField('Name', [
        DataRequired()],
        render_kw={
            'class':'form-control',
            'autocomplete':'off'
            }
        )
    email = StringField('Email', [
        DataRequired()],
        render_kw={
            'class':'form-control',
            'autocomplete':'off'
            }
        )
    message =TextAreaField('Message', [
        DataRequired()],
        render_kw={
            'class':'form-control',
            'rows':'20',
            'autocomplete':'off'
            }
        )



import os
import json

from flask import Blueprint
from flask import render_template
from flask import request

from shopyoapi.enhance import base_context
from shopyoapi.forms import flash_errors

from .forms import PageForm

dirpath = os.path.dirname(os.path.abspath(__file__))
module_info = {}

with open(dirpath + "/info.json") as f:
    module_info = json.load(f)

globals()['{}_blueprint'.format(module_info["module_name"])] = Blueprint(
    "{}".format(module_info["module_name"]),
    __name__,
    template_folder="templates",
    url_prefix=module_info["url_prefix"],
)


module_blueprint = globals()['{}_blueprint'.format(module_info["module_name"])]

module_name = module_info["module_name"]


@module_blueprint.route('/')
def index():
    return ''

@module_blueprint.route(module_info["panel_redirect"])
def panel_redirect():
    context = base_context()
    form = PageForm()

    context.update({
        'form':form,
        'module_name': module_name
    })
    return render_template('page/dashboard.html', **context)


@module_blueprint.route("/check_pagecontent", methods=['GET', 'POST'])
def check_pagecontent():
    if request.method == 'POST':
        form = PageForm()
        if not form.validate_on_submit():
            flash_errors(form)
            return redirect(url_for('{}.panel_redirect'.format(module_name)))

        return form.content.data



import os
import shutil
import sys
import subprocess
import json
import re

from shopyoapi.uploads import add_admin
from shopyoapi.uploads import add_setting

from .file import trymkdir
from .file import trycopytree
from .file import trycopy
from .file import trymkfile

def clean():
    """
    cleans shopyo.db __pycache__ and migrations/

    Parameters
    ----------
    

    Returns
    -------
    None
        ...

    """
    if os.path.exists("shopyo.db"):
        os.remove("shopyo.db")
        print("shopyo.db successfully deleted")
    else:
        print("shopyo.db doesn't exist")
    if os.path.exists("__pycache__"):
        shutil.rmtree("__pycache__")
        print("__pycache__ successfully deleted")
    else:
        print("__pycache__ doesn't exist")
    if os.path.exists("migrations"):
        shutil.rmtree("migrations")
        print("migrations successfully deleted")
    else:
        print("migrations folder doesn't exist")


def initialise():
    """
    Create db, migrate, adds default users, add settings

    Parameters
    ----------
    

    Returns
    -------
    None


    """
    with open("config.json", "r") as config:
        config = json.load(config)
    print("Creating Db")
    print("#######################")
    subprocess.run(
        [sys.executable, "manage.py", "db", "init"], stdout=subprocess.PIPE
    )
    print("Migrating")
    print("#######################")
    subprocess.run(
        [sys.executable, "manage.py", "db", "migrate"], stdout=subprocess.PIPE
    )
    subprocess.run(
        [sys.executable, "manage.py", "db", "upgrade"], stdout=subprocess.PIPE
    )

    print("Initialising User")
    print("#######################")
    add_admin(
        config["admin_user"]["name"],
        config["admin_user"]["password"]
    )

    print("Initialising Settings")
    print("#######################")
    for name, value in config["settings"].items():
        add_setting(name, value)
    print("Done!")


def create_module(modulename):
    """
    creates module with the structure defined in the modules section in docs

    Parameters
    ----------
    modulename: str
        name of module, in alphanumeric-underscore

    Returns
    -------
    None


    """

    if bool(re.match(r'^[A-Za-z0-9_]+$', modulename)) is False:
        print("Error: modulename is not valid, please use alphanumeric and underscore only")
        sys.exit()
    print('creating module: {}'.format(modulename))
    base_path = 'modules/' + modulename
    trymkdir(base_path)
    trymkdir(base_path+'/templates')
    trymkdir(base_path+'/templates/'+modulename)
    view_content = '''
import os
import json

from flask import Blueprint
# from flask import render_template
# from flask import url_for
# from flask import redirect
# from flask import flash
# from flask import request

# from shopyoapi.enhance import base_context
# from shopyoapi.html import notify_success
# from shopyoapi.forms import flash_errors

dirpath = os.path.dirname(os.path.abspath(__file__))
module_info = {}

with open(dirpath + "/info.json") as f:
    module_info = json.load(f)

globals()['{}_blueprint'.format(module_info["module_name"])] = Blueprint(
    "{}".format(module_info["module_name"]),
    __name__,
    template_folder="templates",
    url_prefix=module_info["url_prefix"],
)


module_blueprint = globals()['{}_blueprint'.format(module_info["module_name"])]

@module_blueprint.route("/")
def index():
    return module_info['display_string']
'''
    trymkfile(base_path+'/'+'view.py', view_content)
    trymkfile(base_path+'/'+'forms.py', '')
    trymkfile(base_path+'/'+'models.py', '')
    info_json_content = '''{{
        "display_string": "{0}",
        "module_name":"{1}",
        "type": "show",
        "fa-icon": "fa fa-store",
        "url_prefix": "/{1}",
        "author": {{
            "name":"",
            "website":"",
            "mail":""
        }}
}}'''.format(modulename.capitalize(), modulename)
    trymkfile(base_path+'/'+'info.json', info_json_content)



import shutil
import os


def trycopytree(source, dest):
    """
    Recursive copy of folder

    Parameters
    ----------
    source: str
        source folder path
    dest: str
        destination folder path

    Returns
    -------
    None
    """
    try:
        shutil.copytree(source, dest)
        print("done copying {} to {}".format(source, dest))
    except Exception as e:
        print(e)


def trycopy(source, dest):
    """
    Non-ecursive copy of folder

    Parameters
    ----------
    source: str
        source folder path
    dest: str
        destination folder path

    Returns
    -------
    None
    """
    try:
        shutil.copy(source, dest)
        print("done copying {} to {}".format(source, dest))
    except Exception as e:
        print(e)


def trymkdir(path):
    """
    Creates dir at destination

    Parameters
    ----------
    path: str
        path with folder already in

    Returns
    -------
    None
    """
    try:
        os.mkdir(path)
        print('created dir at', path)
    except Exception as e:
        print(e)


def trymkfile(path, content):
    """
    Creates file

    Parameters
    ----------
    path: str
        path to create file with filename included
    content: str
        file content

    Returns
    -------
    None
    """
    try:
        with open(path, 'w+') as f:
            f.write(content)
        print('file created at {}'.format(path))
        print('with content:')
        print(content)
    except Exception as e:
        print(e)

def absdiroffile(filepath):
    """
    Gives absolute directory of file, normally expects __file__ as
    param

    Parameters
    ----------
    filepath: str
        path of file

    Returns
    -------
    str
        Absolute dir path of file
    """
    return os.path.dirname(os.path.abspath(filepath))


from modules.settings.models import Settings


def get_setting(name):
    """
    Used as key-value lookup from Settings table

    Parameters
    ----------
    name: str
        name of key

    Returns
    -------
    str
        value of key
    """
    s = Settings.query.get(name)
    return s.value


def base_context():
    """
    Used to define global template values


    Returns
    -------
    dict
        copy of dictionary
    """
    base_context = {
        "APP_NAME": get_setting("APP_NAME"),
        "SECTION_NAME": get_setting("SECTION_NAME"),
        "SECTION_ITEMS": get_setting("SECTION_ITEMS"),
    }
    return base_context.copy()



"""empty message

Revision ID: acaae477cfef
Revises: 23a30e62194e
Create Date: 2020-10-08 09:03:05.065918

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'acaae477cfef'
down_revision = '23a30e62194e'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('people', sa.Column('is_manufacturer', sa.Boolean(), nullable=True))
    op.add_column('people', sa.Column('manufacturer_address', sa.String(length=200), nullable=True))
    op.add_column('people', sa.Column('manufacturer_name', sa.String(length=100), nullable=True))
    op.add_column('people', sa.Column('manufacturer_phone', sa.Integer(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('people', 'manufacturer_phone')
    op.drop_column('people', 'manufacturer_name')
    op.drop_column('people', 'manufacturer_address')
    op.drop_column('people', 'is_manufacturer')
    # ### end Alembic commands ###



import sys
import os

from .shopyoapi.file import trymkdir
from .shopyoapi.file import trycopytree
from .shopyoapi.file import trycopy
from .shopyoapi.info import printinfo

from pathlib import Path
import os
import sys
import subprocess

dirpath = Path(__file__).parent.absolute()
dirpathparent = Path(__file__).parent.parent.absolute()

def new_project(path, newfoldername):
    newfoldername = newfoldername.strip('/').strip('\\')
    print("creating new project {}".format(newfoldername))

    base_path = path + "/" + newfoldername
    trymkdir(base_path)
    print("created dir {} in {}".format(newfoldername, path))

    trycopytree(os.path.join(dirpath, "static"), base_path + "/static")
    trycopytree(os.path.join(dirpath, "tests"), base_path + "/tests")
    trycopytree(os.path.join(dirpath, "modules", "base"), base_path + "/modules/base")
    trycopytree(os.path.join(dirpath, "modules", "admin"), base_path + "/modules/admin")
    trycopytree(os.path.join(dirpath, "modules", "login"), base_path + "/modules/login")
    trycopytree(os.path.join(dirpath, "modules", "appointment"), base_path + "/modules/appointment")
    trycopytree(os.path.join(dirpath, "modules", "category"), base_path + "/modules/category")
    trycopytree(os.path.join(dirpath, "modules", "people"), base_path + "/modules/people")
    trycopytree(os.path.join(dirpath, "modules", "product"), base_path + "/modules/product")
    trycopytree(os.path.join(dirpath, "modules", "control_panel"), base_path + "/modules/control_panel")
    trycopytree(os.path.join(dirpath, "modules", "settings"), base_path + "/modules/settings")
    trycopytree(os.path.join(dirpath, "shopyoapi"), base_path + "/shopyoapi")

    trycopy(os.path.join(dirpath, "app.py"), base_path + "/app.py")
    trycopy(os.path.join(dirpath, "config.json"), base_path + "/config.json")
    trycopy(os.path.join(dirpath, "config.py"), base_path + "/config.py")
    trycopy(os.path.join(dirpath, "manage.py"), base_path + "/manage.py")
    trycopy(os.path.join(dirpathparent, "requirements.txt"), base_path + "/requirements.txt")
    trycopy(os.path.join(dirpathparent, "README.md"), base_path + "/README.md")

def main():
    args = sys.argv
    if args[1] == "new" and len(args) == 4:
        printinfo()
        new_project(args[2], args[3])
    else:
        torun = [sys.executable, 'manage.py'] + args[1:]
        subprocess.run(
            torun, stdout=subprocess.PIPE
        )


if __name__ == "__main__":
    main()